summaryrefslogtreecommitdiffstats
path: root/lib/util/urlutil.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/util/urlutil.h')
-rw-r--r--lib/util/urlutil.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/lib/util/urlutil.h b/lib/util/urlutil.h
index 39615858..4a063961 100644
--- a/lib/util/urlutil.h
+++ b/lib/util/urlutil.h
@@ -50,27 +50,27 @@ namespace URLUtil
*/
TQString directory(const TQString & pathName);
/**
* @return The relative path between a tqparent and child URL, or blank if the specified
* child is not a child of tqparent.
* @param tqparent The tqparent URL.
* @param child The child URL.
* @param slashPolicy If tqparent and child are equal then the function returns "/" if
* slashPolicy contains SLASH_PREFIX and otherwise "".\n"/" is appended to a result
* if slashPolicy contains SLASH_SUFFIX.\n"/" is prepended to a result if
* slashPolicy contains SLASH_PREFIX.
*/
- TQString relativePath(const KURL & tqparent, const KURL & child, uint slashPolicy = SLASH_PREFIX);
+ TQString relativePath(const KURL & parent, const KURL & child, uint slashPolicy = SLASH_PREFIX);
/**
* @return The relative path between a tqparent and child URL, or blank if the specified
* child is not a child of tqparent.
* @param tqparent The tqparent URL.
* @param child The child URL.
* @param slashPolicy If tqparent and child are equal then the function returns "/" if
* slashPolicy contains SLASH_PREFIX and otherwise "".\n"/" is appended to a result
* if slashPolicy contains SLASH_SUFFIX.\n"/" is prepended to a result if
* slashPolicy contains SLASH_PREFIX.
*/
- TQString relativePath(const TQString & tqparent, const TQString & child, uint slashPolicy = SLASH_PREFIX);
+ TQString relativePath(const TQString & parent, const TQString & child, uint slashPolicy = SLASH_PREFIX);
/**
* @return The relative path between a base path and destination path or.
* @param base The base Path.
@@ -50,27 +50,27 @@ namespace URLUtil
TQString directory(const TQString & pathName);
/**
- * @return The relative path between a tqparent and child URL, or blank if the specified
- * child is not a child of tqparent.
- * @param tqparent The tqparent URL.
+ * @return The relative path between a parent and child URL, or blank if the specified
+ * child is not a child of parent.
+ * @param parent The parent URL.
* @param child The child URL.
@@ -50,27 +50,27 @@ namespace URLUtil
* @param child The child URL.
- * @param slashPolicy If tqparent and child are equal then the function returns "/" if
+ * @param slashPolicy If parent and child are equal then the function returns "/" if
* slashPolicy contains SLASH_PREFIX and otherwise "".\n"/" is appended to a result
* if slashPolicy contains SLASH_SUFFIX.\n"/" is prepended to a result if
@@ -50,27 +50,27 @@ namespace URLUtil
/**
- * @return The relative path between a tqparent and child URL, or blank if the specified
- * child is not a child of tqparent.
- * @param tqparent The tqparent URL.
+ * @return The relative path between a parent and child URL, or blank if the specified
+ * child is not a child of parent.
+ * @param parent The parent URL.
* @param child The child URL.
@@ -50,27 +50,27 @@ namespace URLUtil
* @param child The child URL.
- * @param slashPolicy If tqparent and child are equal then the function returns "/" if
+ * @param slashPolicy If parent and child are equal then the function returns "/" if
* slashPolicy contains SLASH_PREFIX and otherwise "".\n"/" is appended to a result
* if slashPolicy contains SLASH_SUFFIX.\n"/" is prepended to a result if